'use strict';

var inquirer = require('inquirer');

var open = require('opn');

var chalk = require('chalk');

var resolve = require('../resolve');

var getConfigFilePath = require('../getConfigFilePath');

var renderClear = require('../renderClear');
/**
 * @param {Object} results - the results object
 * @param {Function} originResolve - the origin resolve callback
 * @param {Object} oldResults - the pSeries results
 * @param {Object} di - dependency injection
 * @returns {Object} config - returns the contributebuddy config
 **/


function fetchInitComplete(results, originResolve, oldResults, _ref) {
  var _renderClear = _ref._renderClear,
      _getConfigFilePath = _ref._getConfigFilePath,
      _inquirer = _ref._inquirer,
      _open = _ref._open;
  var labelTitle = chalk.inverse.bold('Init complete 👏!\n\n');
  var labelText = '\nInit complete!\nYou can change the config by editing "./.contributebuddy/config.json"\nRun "contribute-buddy run" to start.\n\n';
  var links = [{
    title: 'Open config file'
  }, {
    title: 'Open contribute-buddy on github',
    href: 'https://github.com/smollweide/contribute-buddy'
  }, {
    title: 'Report improvment or issue on github',
    href: 'https://github.com/smollweide/contribute-buddy/issues/new'
  }];
  var linksTitles = [];
  var linksValues = [];
  links.forEach(function (_ref2) {
    var title = _ref2.title,
        href = _ref2.href;
    linksTitles.push(title);
    linksValues.push(href);
  });

  var prompt = function prompt(pResolve) {
    _renderClear();

    _inquirer.prompt([{
      type: 'list',
      choices: linksTitles.concat(['Continue']),
      name: 'completed',
      message: "".concat(labelTitle).concat(labelText),
      "default": 'Continue',
      prefix: ''
    }]).then(function (_ref3) {
      var completed = _ref3.completed;
      var index = linksTitles.indexOf(completed);

      if (completed === 'Open config file') {
        _open(_getConfigFilePath());

        prompt(originResolve || pResolve);
      } else if (index >= 0) {
        _open(linksValues[index]);

        prompt(originResolve || pResolve);
      } else {
        pResolve();
      }
    });
  };

  if (originResolve) {
    return;
  }

  return new Promise(prompt);
}

module.exports = resolve(fetchInitComplete, {
  renderClear: renderClear,
  getConfigFilePath: getConfigFilePath,
  inquirer: inquirer,
  open: open
});
module.exports.fetchInitComplete = fetchInitComplete;