'use strict';

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var chalk = require('chalk');

var inquirer = require('inquirer');

var open = require('opn');

var resolve = require('../resolve');

var getLabel = require('../getLabel');

var getCompleteObject = require('../getCompleteObject');

var renderClear = require('../renderClear');

var getUserStorage = require('../getUserStorage');
/**
 * @param {Object} sectionsObject - the sections object including selected key and index
 * @param {Object} topicObject - the topic object including index
 * @param {Function} originResolve - the origin resolve callback
 * @param {Object} di - dependency injection
 * @returns {Object} config - returns the contributebuddy config
 **/


function fetchTopic(_ref, _ref2, originResolve, _ref3) {
  var sections = _ref.sections,
      sectionKey = _ref.sectionKey,
      sectionIndex = _ref.sectionIndex;
  var topicKey = _ref2.topicKey,
      topicIndex = _ref2.topicIndex;
  var _inquirer = _ref3._inquirer,
      _process = _ref3._process,
      _open = _ref3._open,
      _renderClear = _ref3._renderClear,
      _getUserStorage = _ref3._getUserStorage,
      _console = _ref3._console;

  var store = _getUserStorage();

  var storeFiledName = "".concat(sectionKey, "/").concat(topicKey); // prompt topic just in case contributer didn't read it yet

  if (store.readmes && store.readmes[storeFiledName] && store.readmes[storeFiledName].oldValue === JSON.stringify(sections[sectionKey].topics[topicKey])) {
    return new Promise(function (pResolve) {
      pResolve({});
    });
  }

  var prompt = function prompt(pResolve) {
    _renderClear();

    var linksTitles = [];
    var linksValues = [];
    (sections[sectionKey].topics[topicKey].links || []).forEach(function (link) {
      var key = Object.keys(link)[0];
      linksTitles.push(getLabel('link', {
        label: key
      }));
      linksValues.push(link[key]);
    });
    var title = chalk.inverse.bold("".concat(sectionIndex + 1, ".").concat(topicIndex + 1, ": ").concat(topicKey));

    _console.log("".concat(title, "\n\n").concat(sections[sectionKey].topics[topicKey].text));

    _inquirer.prompt([{
      type: 'list',
      choices: linksTitles.concat(['Continue', 'Leave']),
      name: topicKey,
      message: 'Please select',
      "default": 'Continue',
      prefix: ''
    }]).then(function (answers) {
      if (answers[topicKey] === 'Leave') {
        _process.exit();
      }

      var index = linksTitles.indexOf(answers[topicKey]);

      if (index >= 0) {
        _open(linksValues[index]);

        prompt(originResolve || pResolve);
        return;
      }

      (originResolve || pResolve)(_defineProperty({}, storeFiledName, getCompleteObject(sections[sectionKey].topics[topicKey])));
    });
  };

  if (originResolve) {
    return new Promise(function (pResolve) {
      pResolve({});
    });
  }

  return new Promise(prompt);
}

module.exports = resolve(fetchTopic, {
  inquirer: inquirer,
  process: process,
  open: open,
  renderClear: renderClear,
  getUserStorage: getUserStorage,
  console: console
});
module.exports.fetchTopic = fetchTopic;