'use strict';

var inquirer = require('inquirer');

var resolve = require('../resolve');

var getLabel = require('../getLabel');

var getUserStorage = require('../getUserStorage');

var setUserStorage = require('../setUserStorage');
/**
 * @param {Object} results - the results object
 * @param {Object} di - dependency injection
 * @returns {void}
 **/


function fetchUsername(results, _ref) {
  var _inquirer = _ref._inquirer,
      _getUserStorage = _ref._getUserStorage,
      _setUserStorage = _ref._setUserStorage,
      _console = _ref._console;

  var userStorage = _getUserStorage();

  return new Promise(function (pResolve) {
    if (!userStorage.username) {
      // TODO validate answer
      _inquirer.prompt([{
        type: 'input',
        name: 'username',
        message: getLabel('username.missing', {})
      }]).then(function (_ref2) {
        var username = _ref2.username;
        userStorage.username = username;

        _setUserStorage(userStorage);

        _console.log(getLabel('username.stored', {
          username: username
        }));

        pResolve({
          username: username
        });
      });
    } else {
      pResolve({});
    }
  });
}

module.exports = resolve(fetchUsername, {
  inquirer: inquirer,
  getUserStorage: getUserStorage,
  setUserStorage: setUserStorage,
  console: console
});
module.exports.fetchUsername = fetchUsername;