'use strict';

var inquirer = require('inquirer');

var chalk = require('chalk');

var resolve = require('../resolve');

var getLabel = require('../getLabel');

var getPackage = require('../getPackage');

var getUserStorage = require('../getUserStorage');

var setUserStorage = require('../setUserStorage');

var renderClear = require('../renderClear');
/**
 * @param {Object} results - the results object
 * @param {Object} di - dependency injection
 * @returns {Object} config - returns the contributebuddy config
 **/


function fetchWelcome(results, _ref) {
  var _getPackage = _ref._getPackage,
      _getUserStorage = _ref._getUserStorage,
      _setUserStorage = _ref._setUserStorage,
      _renderClear = _ref._renderClear,
      _inquirer = _ref._inquirer,
      _process = _ref._process;

  var userStorage = _getUserStorage();

  var packageData = _getPackage();

  return new Promise(function (pResolve) {
    if (!userStorage.welcome) {
      var lableOptions = {
        name: userStorage.username,
        packageName: packageData.name
      };
      var labelTitle = chalk.inverse.bold(getLabel('welcome.first.visit.title', lableOptions));
      var labelText = getLabel('welcome.first.visit', lableOptions);

      _renderClear();

      _inquirer.prompt([{
        type: 'list',
        choices: ['Continue', 'Leave'],
        name: 'welcome',
        message: "".concat(labelTitle).concat(labelText),
        "default": 'Continue',
        prefix: ''
      }]).then(function (_ref2) {
        var welcome = _ref2.welcome;

        if (welcome !== 'Continue') {
          _process.exit();
        }

        userStorage.welcome = true;

        _setUserStorage(userStorage);

        pResolve({
          welcome: true
        });
      });
    } else {
      pResolve({});
    }
  });
}

module.exports = resolve(fetchWelcome, {
  getPackage: getPackage,
  getUserStorage: getUserStorage,
  setUserStorage: setUserStorage,
  renderClear: renderClear,
  inquirer: inquirer,
  process: process
});
module.exports.fetchWelcome = fetchWelcome;