"use strict";

var chalk = require('chalk');

var leftPad = require('left-pad');

var symbols = {
  "default": {
    title: function title(text) {
      return chalk.blue.bgWhite.bold(text);
    },
    titleStopped: function titleStopped(text) {
      return chalk.red.bgWhite.bold(text);
    },
    msg: function msg(text) {
      return text;
    },
    error: function error(text) {
      return chalk.red(text);
    },
    titleSpace: chalk.bgWhite(' '),
    topLeft: chalk.white('┌'),
    topRight: chalk.white('┐'),
    content: chalk.white('│'),
    separatorTop: chalk.white('─'),
    separatorBottom: chalk.white('─'),
    bottomLeft: chalk.white('└'),
    bottomRight: chalk.white('┘')
  },
  code: {
    title: function title(text) {
      return chalk.white.bgBlackBright.bold(text);
    },
    titleStopped: function titleStopped(text) {
      return chalk.red.bgBlackBright.bold(text);
    },
    msg: function msg(text) {
      return chalk.black.bgWhite(text);
    },
    error: function error(text) {
      return chalk.red.bgWhite(text);
    },
    titleSpace: chalk.bgBlackBright(' '),
    topLeft: " ".concat(chalk.bgBlackBright(' ')),
    topRight: "".concat(chalk.bgBlackBright(' '), " "),
    contentLeft: function contentLeft(num) {
      var numOut;

      if (!num || num < 1) {
        numOut = '   ';
      } else {
        numOut = leftPad(num, 3, 0).replace(/^00/, '  ').replace(/^0/, ' ');
      }

      return " ".concat(chalk.gray.bgWhite(" ".concat(numOut, " \u2502")));
    },
    contentRight: "".concat(chalk.bgWhite(' '), " "),
    separatorTop: chalk.bgBlackBright(' '),
    separatorBottom: chalk.bgWhite(' '),
    bottomLeft: " ".concat(chalk.gray.bgWhite('     │')),
    bottomRight: "".concat(chalk.bgWhite(' '), " ")
  },
  codeInline: {
    msg: function msg(text) {
      return chalk.black.bgWhite(text);
    }
  },
  bold: {
    msg: function msg(text) {
      return chalk.bold(text);
    }
  },
  table: {
    topStart: '┌',
    topCell: '─',
    topEnd: '┐',
    bottomStart: '└',
    bottomCell: '─',
    bottomEnd: '┘',
    headerStart: '│',
    headerCell: function headerCell(text) {
      return " ".concat(text, " ");
    },
    headerVSeparator: '│',
    headerEnd: '│',
    hSeparatorStart: '│',
    hSeparatorCell: '─',
    hSeparatorEnd: '│',
    bodyStart: '│',
    bodyCell: function bodyCell(text) {
      return " ".concat(text, " ");
    },
    bodyVSeparator: '│',
    bodyEnd: '│'
  }
};
module.exports = symbols;